==> jetpack.15.1.1.zip: jetpack/jetpack_vendor/automattic/jetpack-subscribers-dashboard/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.4.2 - 2025-10-06
### Changed
- Update package dependencies. [#45334]

## 0.4.1 - 2025-09-22
### Changed
- Update dependencies. [#44940]

## 0.4.0 - 2025-09-19
### Changed
- Update @wordpress/dataviews package from v7 to v9. [#45213]
- Update package dependencies. [#45173] [#45229]

## 0.3.0 - 2025-09-08
### Changed
- Update @wordpress/dataviews package v5.0.0 → v7.0.0 [#45012]
- Update package dependencies. [#45027] [#45097]

## 0.2.5 - 2025-09-01
### Changed
- Remove unused JavaScript dependencies. [#44813]

### Fixed
- Restore dependency removed in #44813. [#44968]

## 0.2.4 - 2025-08-25
### Changed
- Update dependencies. [#44934]

## 0.2.3 - 2025-08-18
### Added
- Add `typecheck` script to ensure that TypeScript files are type-checked. [#44795]

## 0.2.2 - 2025-08-14
### Changed
- Update package dependencies. [#44701]

## 0.2.1 - 2025-08-11
### Changed
- Update dependencies. [#44673]
- Update package dependencies. [#44677]

## 0.2.0 - 2025-08-04
### Changed
- Update @wordpress/dataviews to 5.0.0. [#44376]
- Update dependencies. [#44551]

## 0.1.24 - 2025-07-28
### Changed
- Update dependencies. [#44432]

## 0.1.23 - 2025-07-21
### Changed
- Update package dependencies. [#44356]

## 0.1.22 - 2025-07-14
### Changed
- Update package dependencies. [#44217] [#44219]

## 0.1.21 - 2025-07-07
### Changed
- Update dependencies. [#44161]
- Update package dependencies. [#44148] [#44151]

## 0.1.20 - 2025-06-30
### Changed
- Update dependencies. [#43971]

## 0.1.19 - 2025-06-24
### Changed
- Update dependencies. [#43971]

## 0.1.18 - 2025-06-23
### Changed
- Update package dependencies. [#44020]

## 0.1.17 - 2025-06-16
### Changed
- Update dependencies. [#43878]
- Update package dependencies. [#43892] [#43951]

## 0.1.16 - 2025-06-09
### Changed
- Internal updates.

## 0.1.15 - 2025-06-05
### Changed
- Update package dependencies. [#43766]

## 0.1.14 - 2025-06-03
### Changed
- Update package dependencies. [#43718] [#43734]

## 0.1.13 - 2025-06-02
### Changed
- Update package dependencies. [#43711] [#43712]

## 0.1.12 - 2025-05-26
### Changed
- Update dependencies. [#43569] [#43578]

## 0.1.11 - 2025-05-19
### Changed
- Update package dependencies. [#43398]

## 0.1.10 - 2025-05-12
### Changed
- Stable release management: Do not ship source files. [#43310]
- Update package dependencies. [#43400]

## 0.1.9 - 2025-05-05
### Changed
- Update package dependencies. [#43326] [#43355] [#43356]

## 0.1.8 - 2025-04-28
### Fixed
- My Jetpack: Fix TypeScript type checking and the corresponding errors. [#43205]

## 0.1.7 - 2025-04-14
### Changed
- Update dependencies. [#43001]

## 0.1.6 - 2025-04-07
### Changed
- Linting: First pass of style coding standards. [#42734]

## 0.1.5 - 2025-04-04
### Changed
- Update package dependencies. [#42806]

## 0.1.4 - 2025-04-02
### Changed
- Update package dependencies. [#42762] [#42809]

## 0.1.3 - 2025-03-31
### Changed
- Update dependencies. [#42678]

## 0.1.2 - 2025-03-24
### Changed
- Update dependencies. [#42564]

## 0.1.1 - 2025-03-18
### Changed
- Update package dependencies. [#42506] [#42509] [#42511]

## 0.1.0 - 2025-03-17
### Added
- Initialize package. [#42066]

==> jetpack.15.3.1.zip: jetpack/jetpack_vendor/automattic/jetpack-subscribers-dashboard/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 0.4.9 - 2025-12-01
### Changed
- Update package dependencies. [#46143]

## 0.4.8 - 2025-11-24
### Changed
- Internal updates.

## 0.4.7 - 2025-11-17
### Changed
- Update package dependencies. [#45915] [#45958]

## 0.4.6 - 2025-11-10
### Changed
- Update package dependencies. [#45735] [#45756]

## 0.4.5 - 2025-11-03
### Changed
- Update package dependencies. [#45652]

## 0.4.4 - 2025-10-27
### Changed
- Update package dependencies. [#45551]

## 0.4.3 - 2025-10-10
### Changed
- Update package dependencies. [#45428]

## 0.4.2 - 2025-10-06
### Changed
- Update package dependencies. [#45334]

## 0.4.1 - 2025-09-22
### Changed
- Update dependencies. [#44940]

## 0.4.0 - 2025-09-19
### Changed
- Update @wordpress/dataviews package from v7 to v9. [#45213]
- Update package dependencies. [#45173] [#45229]

## 0.3.0 - 2025-09-08
### Changed
- Update @wordpress/dataviews package v5.0.0 → v7.0.0 [#45012]
- Update package dependencies. [#45027] [#45097]

## 0.2.5 - 2025-09-01
### Changed
- Remove unused JavaScript dependencies. [#44813]

### Fixed
- Restore dependency removed in #44813. [#44968]

## 0.2.4 - 2025-08-25
### Changed
- Update dependencies. [#44934]

## 0.2.3 - 2025-08-18
### Added
- Add `typecheck` script to ensure that TypeScript files are type-checked. [#44795]

## 0.2.2 - 2025-08-14
### Changed
- Update package dependencies. [#44701]

## 0.2.1 - 2025-08-11
### Changed
- Update dependencies. [#44673]
- Update package dependencies. [#44677]

## 0.2.0 - 2025-08-04
### Changed
- Update @wordpress/dataviews to 5.0.0. [#44376]
- Update dependencies. [#44551]

## 0.1.24 - 2025-07-28
### Changed
- Update dependencies. [#44432]

## 0.1.23 - 2025-07-21
### Changed
- Update package dependencies. [#44356]

## 0.1.22 - 2025-07-14
### Changed
- Update package dependencies. [#44217] [#44219]

## 0.1.21 - 2025-07-07
### Changed
- Update dependencies. [#44161]
- Update package dependencies. [#44148] [#44151]

## 0.1.20 - 2025-06-30
### Changed
- Update dependencies. [#43971]

## 0.1.19 - 2025-06-24
### Changed
- Update dependencies. [#43971]

## 0.1.18 - 2025-06-23
### Changed
- Update package dependencies. [#44020]

## 0.1.17 - 2025-06-16
### Changed
- Update dependencies. [#43878]
- Update package dependencies. [#43892] [#43951]

## 0.1.16 - 2025-06-09
### Changed
- Internal updates.

## 0.1.15 - 2025-06-05
### Changed
- Update package dependencies. [#43766]

## 0.1.14 - 2025-06-03
### Changed
- Update package dependencies. [#43718] [#43734]

## 0.1.13 - 2025-06-02
### Changed
- Update package dependencies. [#43711] [#43712]

## 0.1.12 - 2025-05-26
### Changed
- Update dependencies. [#43569] [#43578]

## 0.1.11 - 2025-05-19
### Changed
- Update package dependencies. [#43398]

## 0.1.10 - 2025-05-12
### Changed
- Stable release management: Do not ship source files. [#43310]
- Update package dependencies. [#43400]

## 0.1.9 - 2025-05-05
### Changed
- Update package dependencies. [#43326] [#43355] [#43356]

## 0.1.8 - 2025-04-28
### Fixed
- My Jetpack: Fix TypeScript type checking and the corresponding errors. [#43205]

## 0.1.7 - 2025-04-14
### Changed
- Update dependencies. [#43001]

## 0.1.6 - 2025-04-07
### Changed
- Linting: First pass of style coding standards. [#42734]

## 0.1.5 - 2025-04-04
### Changed
- Update package dependencies. [#42806]

## 0.1.4 - 2025-04-02
### Changed
- Update package dependencies. [#42762] [#42809]

## 0.1.3 - 2025-03-31
### Changed
- Update dependencies. [#42678]

## 0.1.2 - 2025-03-24
### Changed
- Update dependencies. [#42564]

## 0.1.1 - 2025-03-18
### Changed
- Update package dependencies. [#42506] [#42509] [#42511]

## 0.1.0 - 2025-03-17
### Added
- Initialize package. [#42066]
